package VMOMI::HostHasComponentFailureHostComponentType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
